<TS version="2.1" language="eu">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation type="unfinished">Eskuin-klika helbidea edo etiketa aldatzeko</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation type="unfinished">Sortu helbide berria</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation type="unfinished">&amp;Berria</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation type="unfinished">&amp;Kopiatu</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished">&amp;Itxi</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation type="unfinished">Ezabatu aukeratutako helbideak listatik</translation>
    </message>
    <message>
        <source>Enter address or label to search</source>
        <translation type="unfinished">Bilatzeko, helbide edo etiketa sartu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Uneko fitxategian datuak esportatu</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Esportatu</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished">&amp;Ezabatu</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation type="unfinished">Dirua bidaltzeko helbidea hautatu</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation type="unfinished">Dirua jasotzeko helbidea hautatu</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation type="unfinished">&amp;Aukeratu</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation type="unfinished">Hauek dira zuk dirua jaso dezaketen Bitcoin helbideak. Egiaztatu beti diru-kopurua eta dirua jasoko duen helbidea zuzen egon daitezen, txanponak bidali baino lehen.</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. Use the 'Create new receiving address' button in the receive tab to create new addresses.
Signing is only possible with addresses of the type 'legacy'.</source>
        <translation type="unfinished">Hauek dira ordainketak jasotzeko zure Bitcoin helbideak. Jaso taulako 'Jasotzeko helbide berri bat sortu' botoia erabili helbide berri bat sortzeko.
Sinatzea 'legacy' motako helbideekin soilik da posible</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation type="unfinished">Etiketa &amp;Kopiatu</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished">&amp;Editatu</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation type="unfinished">Helbide lista esportatu</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Komaz bereizitako fitxategia</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <extracomment>An error message. %1 is a stand-in argument for the name of the file we attempted to save to.</extracomment>
        <translation type="unfinished">Akats bat egon da helbide lista %1-ean gordetzen sahiatzean. Mesedez, saiatu berriro.</translation>
    </message>
    <message>
        <source>Sending addresses - %1</source>
        <translation type="unfinished">Bidaltzeko helbideak - %1</translation>
    </message>
    <message>
        <source>Receiving addresses - %1</source>
        <translation type="unfinished">Jasotze helbideak - %1</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Esportazioak huts egin du</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation type="unfinished">Etiketa</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Helbidea</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(etiketarik ez)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation type="unfinished">Pasahitzaren dialogoa</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation type="unfinished">Pasahitza sartu</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation type="unfinished">Pasahitz berria</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation type="unfinished">Pasahitz berria errepiikatu</translation>
    </message>
    <message>
        <source>Show passphrase</source>
        <translation type="unfinished">Pasahitza erakutsi</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation type="unfinished">Diruzorroa enkriptatu</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation type="unfinished">Diruzorroaren pasahitza behar du eragiketa honek, diruzorroa desblokeatzeko.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation type="unfinished">Diruzorroa desblokeatu</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation type="unfinished">Pasahitza aldatu</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation type="unfinished">Diruorroaren enkriptazioa berretsi</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation type="unfinished">Abisua: Diruzorroa enkriptatzen baduzu eta zure pasahitza galtzen baduzu, &lt;b&gt;BITCOIN GUZTIAK GALDUKO DITUZU&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation type="unfinished">Seguru al zaude, zure diruzorroa enkriptatu nahi duzula?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation type="unfinished">Zorroa enkriptatuta</translation>
    </message>
    <message>
        <source>Enter the new passphrase for the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation type="unfinished">Diruzorroaren pasahitz berria sartu. &lt;br/&gt;Mesedez &lt;b&gt; hamar edo gehiago ausazko hizkiko&lt;/b&gt; pasahitza erabili, edo &lt;b&gt; gutxienez zortzi hitz&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase for the wallet.</source>
        <translation type="unfinished">Diruzorroaren pasahitz zahar zein berria sartu.</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Jarraitu</translation>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished">Atzera</translation>
    </message>
    <message>
        <source>Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation type="unfinished">Gogoan izan diruzorroaren enkripzioak ezin dituela zure bitcoinak zure ordenagailuan izan dezakezun malware batengandik lapurtuak izatetik guztiz babestu .</translation>
    </message>
    <message>
        <source>Wallet to be encrypted</source>
        <translation type="unfinished">Enkriptatzeko diruzorroa</translation>
    </message>
    <message>
        <source>Your wallet is about to be encrypted. </source>
        <translation type="unfinished">Zure diruzorroa enkriptatzekotan dago</translation>
    </message>
    <message>
        <source>Your wallet is now encrypted. </source>
        <translation type="unfinished">Zure diruzorroa enkriptatua dago orain.</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation type="unfinished">GARRANTZITSUA: Diruzorroaren segurtasun-kopia, wallet.dat, erabilezina bihurtuko da enkriptazioa burutu ondoren. Ondorioz, segurtasun-kopia berriekin ordezkatu beharko zenituzke zure jada eginik dituzun diruzorroaren kopiak.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation type="unfinished">Diruzorroaren enkriptazioak huts egin du</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation type="unfinished">Diruzorroaren enkriptazioak huts egin du barne-akats baten ondorioz. Zure diruzorroa ez da enkriptatu.</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation type="unfinished">Eman dituzun pasahitzak ez datoz bat.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation type="unfinished">Zorroaren desblokeoak huts egin du</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation type="unfinished">Zorroa desenkriptatzeko sartutako pasahitza okerra da.</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption is incorrect. It contains a null character (ie - a zero byte). If the passphrase was set with a version of this software prior to 25.0, please try again with only the characters up to — but not including — the first null character. If this is successful, please set a new passphrase to avoid this issue in the future.</source>
        <translation type="unfinished">Kartera deszifratzeko sartu den pasahitza ez da zuzena. Karaktere nulua du (adib - zero byte). Passphrasak software honen bertsio bat bazuen 25.0 bertsioaren aurretik, mesedez, saia zaitez berriro karaktere hutsekin, lehen karaktere nulua barne hartu gabe. Arrakasta izanez gero, jar ezazu passphrase berri bat etorkizunean hori saihesteko.</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation type="unfinished">Diruzorroaren pasahitza arrakastaz aldatu da.</translation>
    </message>
    <message>
        <source>Passphrase change failed</source>
        <translation type="unfinished">Passphrase aldaketak porrot egin du.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation type="unfinished">Abisua: Mayuskulak blokeatuak dituzu!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation type="unfinished">IP/Saremaskara</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation type="unfinished">Honarte debekatua </translation>
    </message>
</context>
<context>
    <name>BitcoinApplication</name>
    <message>
        <source>Settings file %1 might be corrupt or invalid.</source>
        <translation type="unfinished">%1 Konfigurazio fitxategian akatsa edo baliogabea izan daiteke</translation>
    </message>
    <message>
        <source>Runaway exception</source>
        <translation type="unfinished">Ranaway exception</translation>
    </message>
    <message>
        <source>A fatal error occurred. %1 can no longer continue safely and will quit.</source>
        <translation type="unfinished">Akats larri bat gertatu zen. %1-ek ezin du segurtasunez jarraitu eta itxi egingo da.</translation>
    </message>
    <message>
        <source>Internal error</source>
        <translation type="unfinished">Barne errorea</translation>
    </message>
    </context>
<context>
    <name>QObject</name>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Akatsa: %1</translation>
    </message>
    <message>
        <source>%1 didn't yet exit safely…</source>
        <translation type="unfinished">%1 ez da oraindik segurtasunez itxi…</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">ezezaguna</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kopurua</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation type="unfinished">%1 e</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation type="unfinished">%1 o</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n minute(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n hour(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>%n year(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">Diruzorro lehenetsia</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>&amp;Overview</source>
        <translation type="unfinished">&amp;Gainbegiratu</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation type="unfinished">Diruzorroaren begirada orokorra ikusi</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation type="unfinished">&amp;Transakzioak</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation type="unfinished">Ikusi transakzioen historia</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation type="unfinished">Irten</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation type="unfinished">Aplikaziotik irten</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation type="unfinished">%1-ri buruz</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation type="unfinished">%1-ri buruzko informazioa azaldu</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation type="unfinished">&amp;Qt-ri buruz</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation type="unfinished">Erakutsi Qt-ren buruzko informazioa</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation type="unfinished">%1-ren konfiguraketa aukerak aldatu</translation>
    </message>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Diruzorro berri bat sortu</translation>
    </message>
    <message>
        <source>&amp;Minimize</source>
        <translation type="unfinished">&amp;Minimizatu</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Diruzorroa:</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">Sarea desaktibatua</translation>
    </message>
    <message>
        <source>Proxy is &lt;b&gt;enabled&lt;/b&gt;: %1</source>
        <translation type="unfinished">Proxya &lt;b&gt;gaituta&lt;/b&gt; dago : %1</translation>
    </message>
    <message>
        <source>Send coins to a Bitcoin address</source>
        <translation type="unfinished">Bidali txanponak Bitcoin helbide batera</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation type="unfinished">Diru-zorroaren segurtasun-kopia beste leku batean.</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation type="unfinished">Diruzorroa enkriptatzeko erabilitako pasahitza aldatu</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation type="unfinished">&amp;Bidali</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation type="unfinished">&amp;Jaso</translation>
    </message>
    <message>
        <source>&amp;Options…</source>
        <translation type="unfinished">&amp;Aukerak...</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet…</source>
        <translation type="unfinished">&amp;Diruzorroa enkriptatu...</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation type="unfinished">Zure diru-zorroari dagozkion giltza pribatuak enkriptatu.</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet…</source>
        <translation type="unfinished">Diruzorroaren &amp;segurtasun kopia egin...</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase…</source>
        <translation type="unfinished">&amp;aldatu pasahitza</translation>
    </message>
    <message>
        <source>Sign &amp;message…</source>
        <translation type="unfinished">sinatu &amp;mezua</translation>
    </message>
    <message>
        <source>Sign messages with your Bitcoin addresses to prove you own them</source>
        <translation type="unfinished">Sinatu mezuak Bitcoinen helbideekin, jabetza frogatzeko.</translation>
    </message>
    <message>
        <source>&amp;Verify message…</source>
        <translation type="unfinished">Mezua &amp;balioztatu</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Bitcoin addresses</source>
        <translation type="unfinished">Egiaztatu mesua Bitcoin helbide espezifikoarekin erregistratu direla ziurtatzeko</translation>
    </message>
    <message>
        <source>&amp;Load PSBT from file…</source>
        <translation type="unfinished">&amp;kargatu PSBT fitxategitik...</translation>
    </message>
    <message>
        <source>Open &amp;URI…</source>
        <translation type="unfinished">Ireki&amp;URI...</translation>
    </message>
    <message>
        <source>Close Wallet…</source>
        <translation type="unfinished">Diruzorroa itxi...</translation>
    </message>
    <message>
        <source>Create Wallet…</source>
        <translation type="unfinished">Diruzorroa sortu...</translation>
    </message>
    <message>
        <source>Close All Wallets…</source>
        <translation type="unfinished">Diru-zorro guztiak itxi...</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation type="unfinished">&amp;Artxiboa</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation type="unfinished">&amp;Ezarpenak</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished">&amp;Laguntza</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation type="unfinished">Fitxen tresna-barra</translation>
    </message>
    <message>
        <source>Syncing Headers (%1%)…</source>
        <translation type="unfinished">Burukoak sinkronizatzen (%1%)...</translation>
    </message>
    <message>
        <source>Synchronizing with network…</source>
        <translation type="unfinished">Sarearekin sinkronizatzen...</translation>
    </message>
    <message>
        <source>Indexing blocks on disk…</source>
        <translation type="unfinished">Diskoko blokeak indexatzen...</translation>
    </message>
    <message>
        <source>Processing blocks on disk…</source>
        <translation type="unfinished">Diskoko blokeak prozesatzen...</translation>
    </message>
    <message>
        <source>Connecting to peers…</source>
        <translation type="unfinished">Pareekin konektatzen...</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation type="unfinished"> Bidalketa-helbideen eta etiketen zerrenda erakutsi</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation type="unfinished">Harrera-helbideen eta etiketen zerrenda erakutsi</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation type="unfinished">&amp;Komando-lerroaren aukerak</translation>
    </message>
    <message numerus="yes">
        <source>Processed %n block(s) of transaction history.</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation type="unfinished">%1 atzetik</translation>
    </message>
    <message>
        <source>Catching up…</source>
        <translation type="unfinished">Harrapatzen...</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation type="unfinished">Jasotako azken blokea duela %1 sortu zen.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation type="unfinished">Honen ondorengo transakzioak oraindik ez daude ikusgai.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Akatsa</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="unfinished">Abisua</translation>
    </message>
    <message>
        <source>Information</source>
        <translation type="unfinished">Informazioa</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation type="unfinished">Eguneratua</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction</source>
        <translation type="unfinished">Partzialki sinatutako Bitcoin transakzioa kargatu</translation>
    </message>
    <message>
        <source>Load PSBT from &amp;clipboard…</source>
        <translation type="unfinished">kargatu PSBT arbeletik...</translation>
    </message>
    <message>
        <source>Load Partially Signed Bitcoin Transaction from clipboard</source>
        <translation type="unfinished">Partzialki sinatutako Bitcoin transakzioa kargatu arbeletik</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Adabegiaren leihoa</translation>
    </message>
    <message>
        <source>&amp;Sending addresses</source>
        <translation type="unfinished">&amp;Helbideak bidaltzen</translation>
    </message>
    <message>
        <source>&amp;Receiving addresses</source>
        <translation type="unfinished">&amp;Helbideak jasotzen</translation>
    </message>
    <message>
        <source>Open a bitcoin: URI</source>
        <translation type="unfinished">Ireki bitcoin bat: URI</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <translation type="unfinished">Diruzorroa zabaldu</translation>
    </message>
    <message>
        <source>Open a wallet</source>
        <translation type="unfinished">Diruzorro bat zabaldu</translation>
    </message>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Diruzorroa itxi</translation>
    </message>
    <message>
        <source>Restore Wallet…</source>
        <extracomment>Name of the menu item that restores wallet from a backup file.</extracomment>
        <translation type="unfinished">Diru-zorroa berrezarri...</translation>
    </message>
    <message>
        <source>Restore a wallet from a backup file</source>
        <extracomment>Status tip for Restore Wallet menu item</extracomment>
        <translation type="unfinished">Berrezarri diru-zorro bat babeskopia artxibo batetik.</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Diruzorro guztiak itxi</translation>
    </message>
    <message>
        <source>No wallets available</source>
        <translation type="unfinished">Ez dago diru-zorrorik eskura</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <extracomment>Label of the input field where the name of the wallet is entered.</extracomment>
        <translation type="unfinished">Diruzorroaren izena</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Lehioa</translation>
    </message>
    <message>
        <source>Zoom</source>
        <translation type="unfinished">Gerturatu</translation>
    </message>
    <message>
        <source>Main Window</source>
        <translation type="unfinished">Lehio nagusia</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation type="unfinished">%1 bezeroa</translation>
    </message>
    <message>
        <source>&amp;Hide</source>
        <translation type="unfinished">&amp;Ezkutatu</translation>
    </message>
    <message>
        <source>S&amp;how</source>
        <translation type="unfinished">E&amp;rakutsi</translation>
    </message>
    <message numerus="yes">
        <source>%n active connection(s) to Bitcoin network.</source>
        <extracomment>A substring of the tooltip.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Click for more actions.</source>
        <extracomment>A substring of the tooltip. "More actions" are available via the context menu.</extracomment>
        <translation type="unfinished">Klikatu ekintza gehiago egiteko</translation>
    </message>
    <message>
        <source>Show Peers tab</source>
        <extracomment>A context menu item. The "Peers tab" is an element of the "Node window".</extracomment>
        <translation type="unfinished">Erakutxi kideen fitxa</translation>
    </message>
    <message>
        <source>Disable network activity</source>
        <extracomment>A context menu item.</extracomment>
        <translation type="unfinished">Sareko jarduera desaktibatu</translation>
    </message>
    <message>
        <source>Enable network activity</source>
        <extracomment>A context menu item. The network activity was disabled previously.</extracomment>
        <translation type="unfinished">Sareko jarduera aktibatu</translation>
    </message>
    <message>
        <source>Error: %1</source>
        <translation type="unfinished">Akatsa: %1</translation>
    </message>
    <message>
        <source>Warning: %1</source>
        <translation type="unfinished">Abisua: %1</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation type="unfinished">Data: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation type="unfinished">Kopurua: %1
</translation>
    </message>
    <message>
        <source>Wallet: %1
</source>
        <translation type="unfinished">Diruzorroa: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation type="unfinished">Mota: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation type="unfinished">Etiketa: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation type="unfinished">Helbidea: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation type="unfinished">Bidalitako transakzioa</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation type="unfinished">Sartutako transakzioa</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;enabled&lt;/b&gt;</source>
        <translation type="unfinished">HD gakoaren sorrera &lt;b&gt;gaituta&lt;/b&gt; dago</translation>
    </message>
    <message>
        <source>HD key generation is &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">HD gakoaren sorrera &lt;b&gt;desgaituta&lt;/b&gt; dago</translation>
    </message>
    <message>
        <source>Private key &lt;b&gt;disabled&lt;/b&gt;</source>
        <translation type="unfinished">Gako pribatua &lt;b&gt;desgaitua&lt;/b&gt;</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;unlocked&lt;/b&gt;</source>
        <translation type="unfinished">Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;desblokeatuta&lt;/b&gt; dago une honetan</translation>
    </message>
    <message>
        <source>Wallet is &lt;b&gt;encrypted&lt;/b&gt; and currently &lt;b&gt;locked&lt;/b&gt;</source>
        <translation type="unfinished">Zorroa &lt;b&gt;enkriptatuta&lt;/b&gt; eta &lt;b&gt;blokeatuta&lt;/b&gt; dago une honetan</translation>
    </message>
    <message>
        <source>Original message:</source>
        <translation type="unfinished">Jatorrizko mezua:</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation type="unfinished">Txanpon aukeraketa</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Zenbat:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte kopurua:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kopurua:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ordainketa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Ordaindu ondoren:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Bueltak:</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation type="unfinished">Zuhaitz modua</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation type="unfinished">Zerrenda modua</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kopurua</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation type="unfinished">Etiketarekin jasoa</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation type="unfinished">Helbidearekin jasoa</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation type="unfinished">Konfirmazioak</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Berretsia</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopiatu &amp;Etiketa</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopia kopurua</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopiatu kuota</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopia kuotaren ondoren</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopiatu byte-ak</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopiatu aldaketa</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation type="unfinished">(%1 blokeatuta)</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(izendapenik ez)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation type="unfinished">(bueltak)</translation>
    </message>
</context>
<context>
    <name>CreateWalletActivity</name>
    <message>
        <source>Create Wallet</source>
        <extracomment>Title of window indicating the progress of creation of a new wallet.</extracomment>
        <translation type="unfinished">Diruzorroa sortu</translation>
    </message>
    <message>
        <source>Creating Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the create wallet progress window which indicates to the user which wallet is currently being created.</extracomment>
        <translation type="unfinished">Diru-zorroa sortzen&lt;b&gt;%1&lt;/b&gt;...</translation>
    </message>
    <message>
        <source>Create wallet failed</source>
        <translation type="unfinished">Diruzorroa sortzen hutsegitea</translation>
    </message>
    <message>
        <source>Create wallet warning</source>
        <translation type="unfinished">Diru-zorroa sortzearen buruzko oharra</translation>
    </message>
    <message>
        <source>Can't list signers</source>
        <translation type="unfinished">Ezin dira sinatzaileak zerrendatu</translation>
    </message>
    </context>
<context>
    <name>LoadWalletsActivity</name>
    <message>
        <source>Load Wallets</source>
        <extracomment>Title of progress window which is displayed when wallets are being loaded.</extracomment>
        <translation type="unfinished">Kargatu diruzorroak</translation>
    </message>
    <message>
        <source>Loading wallets…</source>
        <extracomment>Descriptive text of the load wallets progress window which indicates to the user that wallets are currently being loaded.</extracomment>
        <translation type="unfinished">Diruzorroak kargatzen...</translation>
    </message>
</context>
<context>
    <name>OpenWalletActivity</name>
    <message>
        <source>Open wallet failed</source>
        <translation type="unfinished">Diruzorroa irekitzen hutsegitea</translation>
    </message>
    <message>
        <source>Open wallet warning</source>
        <translation type="unfinished">Diruzorroa irekitzen abisua</translation>
    </message>
    <message>
        <source>Open Wallet</source>
        <extracomment>Title of window indicating the progress of opening of a wallet.</extracomment>
        <translation type="unfinished">Diruzorroa zabaldu</translation>
    </message>
    <message>
        <source>Opening Wallet &lt;b&gt;%1&lt;/b&gt;…</source>
        <extracomment>Descriptive text of the open wallet progress window which indicates to the user which wallet is currently being opened.</extracomment>
        <translation type="unfinished">&lt;b&gt;%1&lt;/b&gt; diruzorroa irekitzen ...</translation>
    </message>
</context>
<context>
    <name>WalletController</name>
    <message>
        <source>Close wallet</source>
        <translation type="unfinished">Diruzorroa itxi</translation>
    </message>
    <message>
        <source>Close all wallets</source>
        <translation type="unfinished">Diruzorro guztiak itxi</translation>
    </message>
    <message>
        <source>Are you sure you wish to close all wallets?</source>
        <translation type="unfinished">Ziur diruzorro guztiak itxi nahi dituzula?</translation>
    </message>
</context>
<context>
    <name>CreateWalletDialog</name>
    <message>
        <source>Create Wallet</source>
        <translation type="unfinished">Diruzorroa sortu</translation>
    </message>
    <message>
        <source>Wallet Name</source>
        <translation type="unfinished">Diruzorroaren izena</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation type="unfinished">Diru-zorroa</translation>
    </message>
    <message>
        <source>Encrypt Wallet</source>
        <translation type="unfinished">Diruzorroa enkriptatu</translation>
    </message>
    <message>
        <source>Advanced Options</source>
        <translation type="unfinished">Aukera aurreratuak</translation>
    </message>
    <message>
        <source>Disable Private Keys</source>
        <translation type="unfinished">Desgaitu gako pribatuak</translation>
    </message>
    <message>
        <source>Make Blank Wallet</source>
        <translation type="unfinished">Egin diruzorro hutsa...</translation>
    </message>
    <message>
        <source>External signer</source>
        <translation type="unfinished">Kanpo sinatzailea</translation>
    </message>
    <message>
        <source>Create</source>
        <translation type="unfinished">Sortu</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation type="unfinished">Helbidea editatu</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation type="unfinished">&amp;Etiketa</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation type="unfinished">&amp;Helbidea</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation type="unfinished">Bidaltzeko helbide berria</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation type="unfinished">Jasotzeko helbidea editatu</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation type="unfinished">Bidaltzeko helbidea editatu</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Ezin da diruzorroa desblokeatu.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation type="unfinished">Giltza berriaren sorrerak huts egin du.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation type="unfinished">Datu direktorio berria sortuko da.</translation>
    </message>
    <message>
        <source>name</source>
        <translation type="unfinished">izena</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation type="unfinished">Bidea existitzen da, eta ez da direktorioa.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation type="unfinished">Ezin da datu direktoria hemen sortu.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation type="unfinished">bertsioa</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation type="unfinished">%1 inguru</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation type="unfinished">Komando lerroaren aukerak</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    <message>
        <source>%1 is shutting down…</source>
        <translation type="unfinished">%1Itzaltzen ari da...</translation>
    </message>
    </context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation type="unfinished">Ongietorri</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation type="unfinished">Ongietorri %1-ra</translation>
    </message>
    <message>
        <source> GB</source>
        <translation type="unfinished">GB</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation type="unfinished">Erabili datu direktorio lehenetsia</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation type="unfinished">Erabili datu direktorio pertsonalizatu bat:</translation>
    </message>
    <message numerus="yes">
        <source>%n GB of space available</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(of %n GB needed)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(%n GB needed for full chain)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message numerus="yes">
        <source>(sufficient to restore backups %n day(s) old)</source>
        <extracomment>Explanatory text on the capability of the current prune target.</extracomment>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Akatsa</translation>
    </message>
</context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Inprimakia</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation type="unfinished">Gainerako blokeen kopurua.</translation>
    </message>
    <message>
        <source>Unknown…</source>
        <translation type="unfinished">Ezezaguna...</translation>
    </message>
    <message>
        <source>calculating…</source>
        <translation type="unfinished">kalkulatzen...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Azken blokearen unea</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation type="unfinished">Aurrerapena</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation type="unfinished">Aurrerapenaren igoera orduko</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Izkutatu</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open bitcoin URI</source>
        <translation type="unfinished">Ireki bitcoin URIa</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation type="unfinished">URI: </translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <extracomment>Tooltip text for button that allows you to paste an address that is in your clipboard.</extracomment>
        <translation type="unfinished">Arbeletik helbidea itsatsi</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation type="unfinished">Aukerak</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation type="unfinished">&amp;Nagusia</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation type="unfinished">Databasearen cache tamaina</translation>
    </message>
    <message>
        <source>IP address of the proxy (e.g. IPv4: 127.0.0.1 / IPv6: ::1)</source>
        <translation type="unfinished">Proxyaren IP helbidea  (IPv4: 127.0.0.1 / IPv6: ::1 adibidez )</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation type="unfinished">Ireki konfigurazio fitxategia</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation type="unfinished">Bezeroaren aukera guztiak hasieratu.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation type="unfinished">&amp;Aukerak Hasieratu</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation type="unfinished">&amp;Sarea</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation type="unfinished">Aditu</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation type="unfinished">Diruaren &amp;kontrolaren ezaugarriak gaitu</translation>
    </message>
    <message>
        <source>Accept connections from outside.</source>
        <translation type="unfinished">Kanpoko konexioak onartu</translation>
    </message>
    <message>
        <source>Allow incomin&amp;g connections</source>
        <translation type="unfinished">Sarbide konexioak baimendu</translation>
    </message>
    <message>
        <source>Proxy &amp;IP:</source>
        <translation type="unfinished">Proxyaren &amp;IP helbidea:</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation type="unfinished">&amp;Portua:</translation>
    </message>
    <message>
        <source>Port of the proxy (e.g. 9050)</source>
        <translation type="unfinished">Proxy portua (9050 adibidez)</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation type="unfinished">&amp;Lehioa</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation type="unfinished">&amp;Pantaila</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation type="unfinished">Erabiltzaile-interfazearen &amp;hizkuntza:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation type="unfinished">Zenbatekoa azaltzeko &amp;unitatea:</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished">&amp;Ados</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished">&amp;Ezeztatu</translation>
    </message>
    <message>
        <source>default</source>
        <translation type="unfinished">lehenetsi</translation>
    </message>
    <message>
        <source>none</source>
        <translation type="unfinished">Bat ere ez</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <extracomment>Window title text of pop-up window shown when the user has chosen to reset options.</extracomment>
        <translation type="unfinished">Berretsi aukeren berrezarpena</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <extracomment>Text explaining that the settings changed will not come into effect until the client is restarted.</extracomment>
        <translation type="unfinished">Bezeroa berrabiarazi behar da aldaketak aktibatzeko.</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <extracomment>Window title text of pop-up box that allows opening up of configuration file.</extracomment>
        <translation type="unfinished">Konfiguraketa aukerak</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">Jarraitu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Akatsa</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation type="unfinished">Aldaketa honek clienta berriro piztea eskatzen du</translation>
    </message>
    </context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation type="unfinished">Inprimakia</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation type="unfinished">Eskuragarri:</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation type="unfinished">Zai:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation type="unfinished">Ez dago eskuragarri:</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation type="unfinished">Saldoa</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation type="unfinished">Guztira:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation type="unfinished">Zure oraingo erabateko saldoa</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation type="unfinished">Transakzio berriak</translation>
    </message>
    </context>
<context>
    <name>PSBTOperationsDialog</name>
    <message>
        <source>Sign Tx</source>
        <translation type="unfinished">Sinatu Tx</translation>
    </message>
    <message>
        <source>Copy to Clipboard</source>
        <translation type="unfinished">Kopiatu arbelera</translation>
    </message>
    <message>
        <source>Save…</source>
        <translation type="unfinished">Gorde...</translation>
    </message>
    <message>
        <source>Close</source>
        <translation type="unfinished">Itxi</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">Gorde transakzioko data</translation>
    </message>
    <message>
        <source>PSBT saved to disk.</source>
        <translation type="unfinished">PSBT diskoan gorde da.</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">zure helbidea</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Kopuru osoa</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">edo</translation>
    </message>
    <message>
        <source>Transaction status is unknown.</source>
        <translation type="unfinished">Transakzioaren egoera ezezaguna da.</translation>
    </message>
</context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation type="unfinished">Ordainketa eskaera akatsa</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <extracomment>Title of Peers Table column which contains the peer's User Agent string.</extracomment>
        <translation type="unfinished">Erabiltzaile agentea</translation>
    </message>
    <message>
        <source>Peer</source>
        <extracomment>Title of Peers Table column which contains a unique number used to identify a connection.</extracomment>
        <translation type="unfinished">Kidea</translation>
    </message>
    <message>
        <source>Sent</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have sent to the peer.</extracomment>
        <translation type="unfinished">Bidalia</translation>
    </message>
    <message>
        <source>Received</source>
        <extracomment>Title of Peers Table column which indicates the total amount of network information we have received from the peer.</extracomment>
        <translation type="unfinished">Jasoa</translation>
    </message>
    <message>
        <source>Address</source>
        <extracomment>Title of Peers Table column which contains the IP/Onion/I2P address of the connected peer.</extracomment>
        <translation type="unfinished">Helbidea</translation>
    </message>
    <message>
        <source>Type</source>
        <extracomment>Title of Peers Table column which describes the type of peer connection. The "type" describes why the connection exists.</extracomment>
        <translation type="unfinished">Mota</translation>
    </message>
    <message>
        <source>Network</source>
        <extracomment>Title of Peers Table column which states the network the peer connected through.</extracomment>
        <translation type="unfinished">Sarea</translation>
    </message>
    </context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Gorde irudia...</translation>
    </message>
    <message>
        <source>&amp;Copy Image</source>
        <translation type="unfinished">&amp;kopiatu irudia</translation>
    </message>
    <message>
        <source>Save QR Code</source>
        <translation type="unfinished">Gorde QR kodea</translation>
    </message>
    <message>
        <source>PNG Image</source>
        <extracomment>Expanded name of the PNG file format. See: https://en.wikipedia.org/wiki/Portable_Network_Graphics.</extracomment>
        <translation type="unfinished">PNG irudia</translation>
    </message>
</context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>Client version</source>
        <translation type="unfinished">Bezeroaren bertsioa</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation type="unfinished">&amp;Informazioa</translation>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished">Orokorra</translation>
    </message>
    <message>
        <source>Datadir</source>
        <translation type="unfinished">Datu direktorioa</translation>
    </message>
    <message>
        <source>Blocksdir</source>
        <translation type="unfinished">Blokeen direktorioa</translation>
    </message>
    <message>
        <source>Startup time</source>
        <translation type="unfinished">Abiatzeko ordua</translation>
    </message>
    <message>
        <source>Network</source>
        <translation type="unfinished">Sarea</translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished">Izena</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation type="unfinished">Konexio kopurua</translation>
    </message>
    <message>
        <source>Wallet: </source>
        <translation type="unfinished">Diruzorroa:</translation>
    </message>
    <message>
        <source>(none)</source>
        <translation type="unfinished">(bat ere ez)</translation>
    </message>
    <message>
        <source>&amp;Reset</source>
        <translation type="unfinished">&amp;Berrezarri</translation>
    </message>
    <message>
        <source>Received</source>
        <translation type="unfinished">Jasoa</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation type="unfinished">Bidalia</translation>
    </message>
    <message>
        <source>&amp;Peers</source>
        <translation type="unfinished">&amp;Kideak</translation>
    </message>
    <message>
        <source>Banned peers</source>
        <translation type="unfinished">Debekatutako kideak</translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished">Bertsioa</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation type="unfinished">Erabiltzaile agentea</translation>
    </message>
    <message>
        <source>Node window</source>
        <translation type="unfinished">Adabegiaren leihoa</translation>
    </message>
    <message>
        <source>Permissions</source>
        <translation type="unfinished">Baimenak</translation>
    </message>
    <message>
        <source>Services</source>
        <translation type="unfinished">Zerbitzuak</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation type="unfinished">Azken blokearen unea</translation>
    </message>
    <message>
        <source>Clear console</source>
        <translation type="unfinished">Garbitu kontsola</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <extracomment>Context menu action to copy the address of a peer.</extracomment>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation type="unfinished">&amp;Deskonektatu</translation>
    </message>
    <message>
        <source>Executing…</source>
        <extracomment>A console message indicating an entered command is currently being executed.</extracomment>
        <translation type="unfinished">Exekutatzen...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation type="unfinished">Bai</translation>
    </message>
    <message>
        <source>No</source>
        <translation type="unfinished">Ez</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Ra</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Tik</translation>
    </message>
    <message>
        <source>Never</source>
        <translation type="unfinished">Inoiz ez</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">Ezezaguna</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation type="unfinished">&amp;Kopurua:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Etiketa:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation type="unfinished">&amp;Mezua:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Garbitu formularioko eremu guztiak.</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Garbitu</translation>
    </message>
    <message>
        <source>Show</source>
        <translation type="unfinished">Erakutsi</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation type="unfinished">Ezabatu</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Kopiatu &amp;URI</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopiatu &amp;Etiketa</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation type="unfinished">Ezin da diruzorroa desblokeatu.</translation>
    </message>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address:</source>
        <translation type="unfinished">Helbidea:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kopurua:</translation>
    </message>
    <message>
        <source>Label:</source>
        <translation type="unfinished">Etiketa:</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Mezua:</translation>
    </message>
    <message>
        <source>Wallet:</source>
        <translation type="unfinished">Diruzorroa:</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation type="unfinished">Kopiatu &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>&amp;Verify</source>
        <translation type="unfinished">&amp;Egiaztatu</translation>
    </message>
    <message>
        <source>&amp;Save Image…</source>
        <translation type="unfinished">&amp;Gorde irudia...</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation type="unfinished">Ordainketaren informazioa</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Izendapen</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Mezua</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(izendapenik ez)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation type="unfinished">(mezurik ez)</translation>
    </message>
    <message>
        <source>Requested</source>
        <translation type="unfinished">Eskatua</translation>
    </message>
</context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Txanponak bidali</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation type="unfinished">automatikoki aukeratua</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation type="unfinished">Zenbat:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation type="unfinished">Byte kopurua:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation type="unfinished">Kopurua:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation type="unfinished">Ordainketa:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation type="unfinished">Ordaindu ondoren:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation type="unfinished">Bueltak:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation type="unfinished">Transakzio kuota:</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation type="unfinished">Kilobyteko</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation type="unfinished">Izkutatu</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation type="unfinished">Gomendatutakoa:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation type="unfinished">Neurrira:</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation type="unfinished">Hainbat jasotzaileri batera bidali</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation type="unfinished">Garbitu formularioko eremu guztiak.</translation>
    </message>
    <message>
        <source>Choose…</source>
        <translation type="unfinished">Aukeratu...</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation type="unfinished">Saldoa:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation type="unfinished">Bidalketa berretsi</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation type="unfinished">Bidali</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation type="unfinished">Kopia kopurua</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation type="unfinished">zenbatekoaren kopia</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation type="unfinished">Kopiatu kuota</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation type="unfinished">Kopia kuotaren ondoren</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation type="unfinished">Kopiatu byte-ak</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation type="unfinished">Kopiatu aldaketa</translation>
    </message>
    <message>
        <source>Sign on device</source>
        <extracomment>"device" usually means a hardware wallet.</extracomment>
        <translation type="unfinished">Sinatu gailuan</translation>
    </message>
    <message>
        <source>Connect your hardware wallet first.</source>
        <translation type="unfinished">Konektatu zure hardware diruzorroa lehenago.</translation>
    </message>
    <message>
        <source>Sign failed</source>
        <translation type="unfinished">Sinadurak hutsegitea</translation>
    </message>
    <message>
        <source>External signer not found</source>
        <extracomment>"External signer" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Kanpo sinatzailea ez da aurkitu</translation>
    </message>
    <message>
        <source>External signer failure</source>
        <extracomment>"External signer" means using devices such as hardware wallets.</extracomment>
        <translation type="unfinished">Kanpo sinatzailearen hutsegitea</translation>
    </message>
    <message>
        <source>Save Transaction Data</source>
        <translation type="unfinished">Gorde transakzioko data</translation>
    </message>
    <message>
        <source>PSBT saved</source>
        <extracomment>Popup message when a PSBT has been saved to a file</extracomment>
        <translation type="unfinished">PSBT gordeta</translation>
    </message>
    <message>
        <source>External balance:</source>
        <translation type="unfinished">Kanpo saldoa:</translation>
    </message>
    <message>
        <source>or</source>
        <translation type="unfinished">edo</translation>
    </message>
    <message>
        <source>Total Amount</source>
        <translation type="unfinished">Kopuru osoa</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation type="unfinished">Txanponen bidalketa berretsi</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation type="unfinished">Ordaintzeko kopurua, 0 baino handiagoa izan behar du.</translation>
    </message>
    <message numerus="yes">
        <source>Estimated to begin confirmation within %n block(s).</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(izendapenik ez)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation type="unfinished">K&amp;opurua:</translation>
    </message>
    <message>
        <source>Pay &amp;To:</source>
        <translation type="unfinished">Ordaindu &amp;honi:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation type="unfinished">&amp;Etiketa:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Aukeratu lehenago aukeraturiko helbidea</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Arbeletik helbidea itsatsi</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation type="unfinished">Mezua:</translation>
    </message>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>Choose previously used address</source>
        <translation type="unfinished">Aukeratu lehenago aukeraturiko helbidea</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation type="unfinished">Arbeletik helbidea itsatsi</translation>
    </message>
    <message>
        <source>Enter the message you want to sign here</source>
        <translation type="unfinished">Sartu sinatu nahi duzun mezua hemen</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation type="unfinished">Sinadura</translation>
    </message>
    <message>
        <source>Sign &amp;Message</source>
        <translation type="unfinished">Sinatu &amp;Mezua</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation type="unfinished">&amp;Egiaztatu mezua</translation>
    </message>
    <message>
        <source>No error</source>
        <translation type="unfinished">Ez dago errorerik</translation>
    </message>
    <message>
        <source>Message signing failed.</source>
        <translation type="unfinished">Errorea mezua sinatzean</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation type="unfinished">Mezua sinatuta.</translation>
    </message>
    <message>
        <source>Please check the signature and try again.</source>
        <translation type="unfinished">Mesedez, begiratu sinadura eta saiatu berriro.</translation>
    </message>
    <message>
        <source>Message verification failed.</source>
        <translation type="unfinished">Mezuen egiaztatzeak huts egin du</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation type="unfinished">Mezua egiaztatua.</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>abandoned</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents an abandoned transaction.</extracomment>
        <translation type="unfinished">abandonatuta</translation>
    </message>
    <message>
        <source>%1/unconfirmed</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in at least one block, but less than 6 blocks.</extracomment>
        <translation type="unfinished">%1/konfirmatu gabe</translation>
    </message>
    <message>
        <source>%1 confirmations</source>
        <extracomment>Text explaining the current status of a transaction, shown in the status field of the details window for this transaction. This status represents a transaction confirmed in 6 or more blocks.</extracomment>
        <translation type="unfinished">%1 konfirmazio</translation>
    </message>
    <message>
        <source>Status</source>
        <translation type="unfinished">Egoera</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Source</source>
        <translation type="unfinished">Iturria</translation>
    </message>
    <message>
        <source>Generated</source>
        <translation type="unfinished">Sortua</translation>
    </message>
    <message>
        <source>From</source>
        <translation type="unfinished">Tik</translation>
    </message>
    <message>
        <source>unknown</source>
        <translation type="unfinished">ezezaguna</translation>
    </message>
    <message>
        <source>To</source>
        <translation type="unfinished">Ra</translation>
    </message>
    <message>
        <source>own address</source>
        <translation type="unfinished">zure helbidea</translation>
    </message>
    <message>
        <source>label</source>
        <translation type="unfinished">etiketa</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation type="unfinished">Kreditua</translation>
    </message>
    <message numerus="yes">
        <source>matures in %n more block(s)</source>
        <translation type="unfinished">
            <numerusform />
            <numerusform />
        </translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation type="unfinished">Onartu gabe</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation type="unfinished">Zorrak</translation>
    </message>
    <message>
        <source>Total debit</source>
        <translation type="unfinished">Zor totala</translation>
    </message>
    <message>
        <source>Total credit</source>
        <translation type="unfinished">Kreditu totala</translation>
    </message>
    <message>
        <source>Message</source>
        <translation type="unfinished">Mezua</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation type="unfinished">Transakzioa</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation type="unfinished">Kopurua</translation>
    </message>
    <message>
        <source>true</source>
        <translation type="unfinished">egia</translation>
    </message>
    <message>
        <source>false</source>
        <translation type="unfinished">faltsua</translation>
    </message>
</context>
<context>
    <name>TransactionDescDialog</name>
    <message>
        <source>This pane shows a detailed description of the transaction</source>
        <translation type="unfinished">Panel honek transakzien deskribapen xehea azaltzen du</translation>
    </message>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Mota</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Izendapen</translation>
    </message>
    <message>
        <source>Unconfirmed</source>
        <translation type="unfinished">Baieztatu gabea</translation>
    </message>
    <message>
        <source>Confirmed (%1 confirmations)</source>
        <translation type="unfinished">Konfirmatuta (%1 konfirmazio)</translation>
    </message>
    <message>
        <source>Generated but not accepted</source>
        <translation type="unfinished">Sortua, baina ez onartua</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Honekin jasoa</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Hona bidalia</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Meatua</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation type="unfinished">(izendapenik ez)</translation>
    </message>
    <message>
        <source>Transaction status. Hover over this field to show number of confirmations.</source>
        <translation type="unfinished">Transakzioaren egoera. Pasatu sagua gainetik konfirmazio kopurua ikusteko.</translation>
    </message>
    <message>
        <source>Date and time that the transaction was received.</source>
        <translation type="unfinished">Transakzioa jasotako data eta ordua.</translation>
    </message>
    <message>
        <source>Type of transaction.</source>
        <translation type="unfinished">Transakzio mota.</translation>
    </message>
    <message>
        <source>Amount removed from or added to balance.</source>
        <translation type="unfinished">Saldoan kendu edo gehitutako kopurua.</translation>
    </message>
</context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation type="unfinished">Denak</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="unfinished">Gaurkoak</translation>
    </message>
    <message>
        <source>This week</source>
        <translation type="unfinished">Aste honetankoak</translation>
    </message>
    <message>
        <source>This month</source>
        <translation type="unfinished">Hil honetakoak</translation>
    </message>
    <message>
        <source>Last month</source>
        <translation type="unfinished">Azken hilekoak</translation>
    </message>
    <message>
        <source>This year</source>
        <translation type="unfinished">Aurtengoak</translation>
    </message>
    <message>
        <source>Received with</source>
        <translation type="unfinished">Honekin jasoa</translation>
    </message>
    <message>
        <source>Sent to</source>
        <translation type="unfinished">Hona bidalia</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation type="unfinished">Meatua</translation>
    </message>
    <message>
        <source>Other</source>
        <translation type="unfinished">Beste</translation>
    </message>
    <message>
        <source>Min amount</source>
        <translation type="unfinished">Kopuru minimoa</translation>
    </message>
    <message>
        <source>&amp;Copy address</source>
        <translation type="unfinished">&amp;Helbidea kopiatu</translation>
    </message>
    <message>
        <source>Copy &amp;label</source>
        <translation type="unfinished">Kopiatu &amp;Etiketa</translation>
    </message>
    <message>
        <source>Comma separated file</source>
        <extracomment>Expanded name of the CSV file format. See: https://en.wikipedia.org/wiki/Comma-separated_values.</extracomment>
        <translation type="unfinished">Komaz bereizitako fitxategia</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation type="unfinished">Berretsia</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="unfinished">Data</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished">Mota</translation>
    </message>
    <message>
        <source>Label</source>
        <translation type="unfinished">Izendapen</translation>
    </message>
    <message>
        <source>Address</source>
        <translation type="unfinished">Helbidea</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation type="unfinished">Esportazioak huts egin du</translation>
    </message>
    </context>
<context>
    <name>WalletFrame</name>
    <message>
        <source>Create a new wallet</source>
        <translation type="unfinished">Diruzorro berri bat sortu</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Akatsa</translation>
    </message>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation type="unfinished">Txanponak bidali</translation>
    </message>
    <message>
        <source>Current fee:</source>
        <translation type="unfinished">Oraingo kuota:</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation type="unfinished">Kuota berria:</translation>
    </message>
    <message>
        <source>PSBT copied</source>
        <translation type="unfinished">PSBT kopiatua</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation type="unfinished">&amp;Esportatu</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation type="unfinished">Uneko fitxategian datuak esportatu</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>default wallet</source>
        <translation type="unfinished">Diruzorro lehenetsia</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation type="unfinished">Zamaketa amaitua</translation>
    </message>
    <message>
        <source>Loading wallet…</source>
        <translation type="unfinished">Diruzorroa kargatzen...</translation>
    </message>
    <message>
        <source>Missing amount</source>
        <translation type="unfinished">Zenbatekoa falta da</translation>
    </message>
    <message>
        <source>No addresses available</source>
        <translation type="unfinished">Ez dago helbiderik eskuragarri</translation>
    </message>
    <message>
        <source>Replaying blocks…</source>
        <translation type="unfinished">Blokeak errepikatzen...</translation>
    </message>
    <message>
        <source>Rescanning…</source>
        <translation type="unfinished">Bereskaneatzen...</translation>
    </message>
    <message>
        <source>Starting network threads…</source>
        <translation type="unfinished">Sareko hariak abiarazten...</translation>
    </message>
    <message>
        <source>The source code is available from %s.</source>
        <translation type="unfinished">Iturri kodea %s-tik dago eskuragarri.</translation>
    </message>
    <message>
        <source>The transaction amount is too small to pay the fee</source>
        <translation type="unfinished">Transakzio kantitatea txikiegia da kuota ordaintzeko.</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation type="unfinished">Hau software esperimentala da</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation type="unfinished">transakzio kopurua txikiegia</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation type="unfinished">Transakzio luzeegia</translation>
    </message>
    <message>
        <source>Verifying blocks…</source>
        <translation type="unfinished">Blokeak egiaztatzen...</translation>
    </message>
    <message>
        <source>Verifying wallet(s)…</source>
        <translation type="unfinished">Diruzorroak egiaztatzen...</translation>
    </message>
    </context>
</TS>